#' @importFrom fuj %||%
fuj::`%||%`

#' @importFrom fuj %:::%
#' @export
fuj::`%:::%`

#' @importFrom fuj %::%
#' @export
fuj::`%::%`

#' @importFrom fuj %colons%
#' @export
fuj::`%colons%`

#' @importFrom fuj %len%
fuj::`%len%`

#' @importFrom fuj %names%
#' @export
fuj::`%names%`

#' @importFrom fuj %out%
#' @export
fuj::`%out%`

#' @importFrom fuj %wi%
#' @export
fuj::`%wi%`

#' @importFrom fuj %wo%
#' @export
fuj::`%wo%`

#' @importFrom fuj any_match
#' @export
fuj::any_match

#' @importFrom fuj exattr
fuj::exattr

#' @importFrom fuj flip
#' @export
fuj::flip

#' @importFrom fuj is_linux
#' @export
fuj::is_linux

#' @importFrom fuj is_macos
fuj::is_macos

#' @importFrom fuj is_windows
fuj::is_windows

#' @importFrom fuj set_names
#' @export
fuj::set_names

#' @importFrom fuj is_named
fuj::is_named

#' @importFrom fuj remove_names
#' @export
fuj::remove_names

#' @importFrom fuj muffle
#' @export
fuj::muffle

#' @importFrom fuj wuffle
#' @export
fuj::wuffle

#' @importFrom fuj no_match
#' @export
fuj::no_match

#' @importFrom fuj quick_df
#' @export
fuj::quick_df

#' @importFrom fuj quick_dfl
#' @export
fuj::quick_dfl

#' @importFrom fuj require_namespace
#' @export
fuj::require_namespace

#' @importFrom fuj struct
#' @export
fuj::struct
